benzina.torch.operations
========================

.. automodule:: benzina.torch.operations
  :members:
  :exclude-members: OOBTransform, ColorTransform, ConstantOOBTransform, ConstantColorTransform
  :noindex:
